Class: MaxMind::GeoIP2::Record::AnonymizerFeed

Inherits:
Abstract
  • Object
show all
Defined in:
lib/maxmind/geoip2/record/anonymizer_feed.rb

Overview

Contains data for one type of anonymizer detection, currently residential proxies. Additional feeds may be added in the future.

This record is returned by the anonymizer object of the Insights web service.

Instance Method Summary collapse

Instance Method Details

#confidenceInteger?

A score ranging from 1 to 99 that represents our percent confidence that the network is currently part of this anonymizer feed. This property is only available from Insights.

Returns:

  • (Integer, nil)


20
21
22
# File 'lib/maxmind/geoip2/record/anonymizer_feed.rb', line 20

def confidence
  get('confidence')
end

#network_last_seenDate?

The last day that the network was sighted in our analysis of this anonymizer feed. This value is parsed lazily. This property is only available from Insights.

Returns:

  • (Date, nil)

    A Date object representing the last seen date, or nil if the date is not available.



30
31
32
33
34
35
36
37
38
39
40
41
# File 'lib/maxmind/geoip2/record/anonymizer_feed.rb', line 30

def network_last_seen
  return @network_last_seen if defined?(@network_last_seen)

  date_string = get('network_last_seen')

  if !date_string
    @network_last_seen = nil
    return nil
  end

  @network_last_seen = Date.parse(date_string)
end

#provider_nameString?

The name of the provider associated with the network in this anonymizer feed. This property is only available from Insights.

Returns:

  • (String, nil)


47
48
49
# File 'lib/maxmind/geoip2/record/anonymizer_feed.rb', line 47

def provider_name
  get('provider_name')
end